#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lens
version:              5.2.3
visibility:           public
id:                   lens-5.2.3-BvPGCNowJJEJ41IL4OiKRj
key:                  lens-5.2.3-BvPGCNowJJEJ41IL4OiKRj
license:              BSD-2-Clause
copyright:            Copyright (C) 2012-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens/
synopsis:             Lenses, Folds and Traversals
description:
    This package comes \"Batteries Included\" with many useful lenses for the types
    commonly used from the Haskell Platform, and with tools for automatically
    generating lenses and isomorphisms for user-supplied data types.

    The combinators in @Control.Lens@ provide a highly generic toolbox for composing
    families of getters, folds, isomorphisms, traversals, setters and lenses and their
    indexed variants.

    An overview, with a large number of examples can be found in the <https://github.com/ekmett/lens#lens-lenses-folds-and-traversals README>.

    An introductory video on the style of code used in this library by Simon Peyton Jones is available from <http://skillsmatter.com/podcast/scala/lenses-compositional-data-access-and-manipulation Skills Matter>.

    A video on how to use lenses and how they are constructed is available on <http://youtu.be/cefnmjtAolY?hd=1 youtube>.

    Slides for that second talk can be obtained from <http://comonad.com/haskell/Lenses-Folds-and-Traversals-NYC.pdf comonad.com>.

    More information on the care and feeding of lenses, including a brief tutorial and motivation
    for their types can be found on the <https://github.com/ekmett/lens/wiki lens wiki>.

    A small game of @pong@ and other more complex examples that manage their state using lenses can be found in the <https://github.com/ekmett/lens/blob/master/examples/ example folder>.

    /Lenses, Folds and Traversals/

    With some signatures simplified, the core of the hierarchy of lens-like constructions looks like:


    <<http://i.imgur.com/ALlbPRa.png>>

    <https://raw.githubusercontent.com/ekmett/lens/master/images/Hierarchy.png (Local Copy)>

    You can compose any two elements of the hierarchy above using @(.)@ from the @Prelude@, and you can
    use any element of the hierarchy as any type it linked to above it.

    The result is their lowest upper bound in the hierarchy (or an error if that bound doesn'\''t exist).

    For instance:

    * You can use any '\''Traversal'\'' as a '\''Fold'\'' or as a '\''Setter'\''.

    * The composition of a '\''Traversal'\'' and a '\''Getter'\'' yields a '\''Fold'\''.

    /Minimizing Dependencies/

    If you want to provide lenses and traversals for your own types in your own libraries, then you
    can do so without incurring a dependency on this (or any other) lens package at all.

    /e.g./ for a data type:

    > data Foo a = Foo Int Int a

    You can define lenses such as

    > -- bar :: Lens'\'' (Foo a) Int
    > bar :: Functor f => (Int -> f Int) -> Foo a -> f (Foo a)
    > bar f (Foo a b c) = fmap (\a'\'' -> Foo a'\'' b c) (f a)

    > -- quux :: Lens (Foo a) (Foo b) a b
    > quux :: Functor f => (a -> f b) -> Foo a -> f (Foo b)
    > quux f (Foo a b c) = fmap (Foo a b) (f c)

    without the need to use any type that isn'\''t already defined in the @Prelude@.

    And you can define a traversal of multiple fields with '\''Control.Applicative.Applicative'\'':

    > -- traverseBarAndBaz :: Traversal'\'' (Foo a) Int
    > traverseBarAndBaz :: Applicative f => (Int -> f Int) -> Foo a -> f (Foo a)
    > traverseBarAndBaz f (Foo a b c) = Foo <$> f a <*> f b <*> pure c

    What is provided in this library is a number of stock lenses and traversals for
    common haskell types, a wide array of combinators for working them, and more
    exotic functionality, (/e.g./ getters, setters, indexed folds, isomorphisms).

category:             Data, Lenses, Generics
abi:                  2c248d60ffa264e57cf4c80be84f911b
exposed:              True
exposed-modules:
    Control.Exception.Lens Control.Lens Control.Lens.At
    Control.Lens.Combinators Control.Lens.Cons Control.Lens.Each
    Control.Lens.Empty Control.Lens.Equality Control.Lens.Extras
    Control.Lens.Fold Control.Lens.Getter Control.Lens.Indexed
    Control.Lens.Internal Control.Lens.Internal.Bazaar
    Control.Lens.Internal.ByteString Control.Lens.Internal.CTypes
    Control.Lens.Internal.Context Control.Lens.Internal.Deque
    Control.Lens.Internal.Doctest Control.Lens.Internal.Exception
    Control.Lens.Internal.FieldTH Control.Lens.Internal.Fold
    Control.Lens.Internal.Getter Control.Lens.Internal.Indexed
    Control.Lens.Internal.Instances Control.Lens.Internal.Iso
    Control.Lens.Internal.Level Control.Lens.Internal.List
    Control.Lens.Internal.Magma Control.Lens.Internal.Prism
    Control.Lens.Internal.PrismTH Control.Lens.Internal.Profunctor
    Control.Lens.Internal.Review Control.Lens.Internal.Setter
    Control.Lens.Internal.TH Control.Lens.Internal.Zoom
    Control.Lens.Iso Control.Lens.Lens Control.Lens.Level
    Control.Lens.Operators Control.Lens.Plated Control.Lens.Prism
    Control.Lens.Profunctor Control.Lens.Reified Control.Lens.Review
    Control.Lens.Setter Control.Lens.TH Control.Lens.Traversal
    Control.Lens.Tuple Control.Lens.Type Control.Lens.Unsound
    Control.Lens.Wrapped Control.Lens.Zoom Control.Monad.Error.Lens
    Control.Parallel.Strategies.Lens Control.Seq.Lens Data.Array.Lens
    Data.Bits.Lens Data.ByteString.Lazy.Lens Data.ByteString.Lens
    Data.ByteString.Strict.Lens Data.Complex.Lens Data.Data.Lens
    Data.Dynamic.Lens Data.HashSet.Lens Data.IntSet.Lens Data.List.Lens
    Data.Map.Lens Data.Sequence.Lens Data.Set.Lens Data.Text.Lazy.Lens
    Data.Text.Lens Data.Text.Strict.Lens Data.Tree.Lens
    Data.Typeable.Lens Data.Vector.Generic.Lens Data.Vector.Lens
    GHC.Generics.Lens Language.Haskell.TH.Lens Numeric.Lens
    Numeric.Natural.Lens System.Exit.Lens System.FilePath.Lens
    System.IO.Error.Lens

hidden-modules:       Control.Lens.Internal.Prelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/lens-5.2.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lens-5.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens
hs-libraries:         HSlens-5.2.3-BvPGCNowJJEJ41IL4OiKRj
depends:
    array-0.5.4.0 assoc-1.1-5b6n1DhduSjDRC33U3zPiM base-4.16.4.0
    base-orphans-0.8.8.2-A9lteWCgAuH60hU4SRhxHG
    bifunctors-5.6-APPSW8DCPtI5Bxlj9IXuMl bytestring-0.11.4.0
    call-stack-0.4.0-7Kj6UtaYY94JDoMxAZHX8y
    comonad-5.0.8-8xScyDaACinCtRgnxYXdM4 containers-0.6.5.1
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    distributive-0.6.2.1-2koEeSfM3NQ4osK1XiGjL1 exceptions-0.10.4
    filepath-1.4.2.2 free-5.2-7Yhsn64UzJE902IPfjDtFW ghc-prim-0.8.0
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    indexed-traversable-0.1.4-xp32MAwOI11MXtsfM1sF8
    indexed-traversable-instances-0.1.2-1pMyJbHJiAMFQBKTyz8mLG
    kan-extensions-5.2.6-9yYQL4xEugvB60dX9QW981 mtl-2.2.2
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1
    profunctors-5.6.2-IDT3gQTOCqT1ZN23x5NcdX
    reflection-2.1.8-uMfRpXaIWB6nxe8EdjRvu
    semigroupoids-6.0.0.1-5AcvZpdhiaGIeYnFLxTYAz
    strict-0.5-DIeMHbEEu2RKGxAHg04txz
    tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP template-haskell-2.18.0.0
    text-1.2.5.0 th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu
    these-1.2-KREW16cRXrW4psVJW0Q3fv transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-3rvz4A0dRQ942O2ubs0wBO
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP

haddock-interfaces:   /usr/share/doc/haskell-lens/html/lens.haddock
haddock-html:         /usr/share/doc/haskell-lens/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

